<?php
/**
 * Toko Online Theme Options
 *
 * @package WordPress
 * @subpackage Toko_Online
 * @since Toko Online 1.0
 */

/**
 * Properly enqueue styles and scripts for our theme options page.
 *
 * This function is attached to the admin_enqueue_scripts action hook.
 *
 * @since Toko Online 1.0
 *
 */
function tokokoo_admin_enqueue_scripts( $hook_suffix ) {
	wp_enqueue_style( 'tokokoo-theme-options', get_template_directory_uri() . '/functions/theme-options.css', false, '2011-04-28' );
	wp_enqueue_script( 'tokokoo-theme-options', get_template_directory_uri() . '/functions/theme-options.js', array( 'farbtastic' ), '2011-06-10' );
	wp_enqueue_style( 'farbtastic' );
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'tokokoo_admin_enqueue_scripts' );

/**
 * Register the form setting for our tokokoo_options array.
 *
 * This function is attached to the admin_init action hook.
 *
 * This call to register_setting() registers a validation callback, tokokoo_theme_options_validate(),
 * which is used when the option is saved, to ensure that our option values are complete, properly
 * formatted, and safe.
 *
 * We also use this function to add our theme option if it doesn't already exist.
 *
 * @since Toko Online 1.0
 */
function tokokoo_theme_options_init() {

	// If we have no options in the database, let's add them now.
	if ( false === tokokoo_get_theme_options() )
		add_option( 'tokokoo_theme_options', tokokoo_get_default_theme_options() );

	register_setting(
		'tokokoo_options',       // Options group, see settings_fields() call in theme_options_render_page()
		'tokokoo_theme_options', // Database option, see tokokoo_get_theme_options()
		'tokokoo_theme_options_validate' // The sanitization callback, see tokokoo_theme_options_validate()
	);
}
add_action( 'admin_init', 'tokokoo_theme_options_init' );

/**
 * Change the capability required to save the 'tokokoo_options' options group.
 *
 * @see tokokoo_theme_options_init() First parameter to register_setting() is the name of the options group.
 * @see tokokoo_theme_options_add_page() The edit_theme_options capability is used for viewing the page.
 *
 * By default, the options groups for all registered settings require the manage_options capability.
 * This filter is required to change our theme options page to edit_theme_options instead.
 * By default, only administrators have either of these capabilities, but the desire here is
 * to allow for finer-grained control for roles and users.
 *
 * @param string $capability The capability used for the page, which is manage_options by default.
 * @return string The capability to actually use.
 */
function tokokoo_option_page_capability( $capability ) {
	return 'edit_theme_options';
}
add_filter( 'option_page_capability_tokokoo_options', 'tokokoo_option_page_capability' );

/**
 * Add our theme options page to the admin menu, including some help documentation.
 *
 * This function is attached to the admin_menu action hook.
 *
 * @since Toko Online 1.0
 */
function tokokoo_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'tokokoo' ),   // Name of page
		__( 'Theme Options', 'tokokoo' ),   // Label in menu
		'edit_theme_options',                    // Capability required
		'theme_options',                         // Menu slug, used to uniquely identify the page
		'tokokoo_theme_options_render_page' // Function that renders the options page
	);

	if ( ! $theme_page )
		return;

	$help = '<p>' . __( 'Some themes provide customization options that are grouped together on a Theme Options screen. If you change themes, options may change or disappear, as they are theme-specific. Your current theme, Toko Online, provides the following Theme Options:', 'tokokoo' ) . '</p>' .
			'<ol>' .
				'<li>' . __( '<strong>Color Scheme</strong>: You can choose a color palette of "Light" (light background with dark text) or "Dark" (dark background with light text) for your site.', 'tokokoo' ) . '</li>' .
				'<li>' . __( '<strong>Link Color</strong>: You can choose the color used for text links on your site. You can enter the HTML color or hex code, or you can choose visually by clicking the "Select a Color" button to pick from a color wheel.', 'tokokoo' ) . '</li>' .
				'<li>' . __( '<strong>Default Layout</strong>: You can choose if you want your site&#8217;s default layout to have a sidebar on the left, the right, or not at all.', 'tokokoo' ) . '</li>' .
			'</ol>' .
			'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme options.', 'tokokoo' ) . '</p>' .
			'<p><strong>' . __( 'For more information:', 'tokokoo' ) . '</strong></p>' .
			'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>', 'tokokoo' ) . '</p>' .
			'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>', 'tokokoo' ) . '</p>';

	//add_contextual_help( $theme_page, $help );
}
add_action( 'admin_menu', 'tokokoo_theme_options_add_page' );

/**
 * Returns the default options for Toko Online.
 *
 * @since Toko Online 1.0
 */
function tokokoo_get_default_theme_options() {
	$default_theme_options = array(
		'link_color'   => tokokoo_get_default_link_color( 'light' ),
	);

	return apply_filters( 'tokokoo_default_theme_options', $default_theme_options );
}

/**
 * Returns the default link color for Toko Online, based on color scheme.
 *
 * @since Toko Online 1.0
 *
 * @param $string $color_scheme Color scheme. Defaults to the active color scheme.
 * @return $string Color.
*/
function tokokoo_get_default_link_color( $color_scheme = null ) {
	if ( null === $color_scheme ) {
		$options = tokokoo_get_theme_options();
		$color_scheme = $options['color_scheme'];
	}

	return $color_schemes[ $color_scheme ]['default_link_color'];
}

/**
 * Returns the options array for Toko Online.
 *
 * @since Toko Online 1.0
 */
function tokokoo_get_theme_options() {
	return get_option( 'tokokoo_theme_options', tokokoo_get_default_theme_options() );
}

/**
 * Returns the options array for Toko Online.
 *
 * @since Toko Online 1.2
 */
function tokokoo_theme_options_render_page() {
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php printf( __( '%s Theme Options', 'tokokoo' ), get_current_theme() ); ?></h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
				settings_fields( 'tokokoo_options' );
				$options = tokokoo_get_theme_options();
				$default_options = tokokoo_get_default_theme_options();
			?>

			<table class="form-table">

				<tr valign="top"><th scope="row"><?php _e( 'Background Color', 'tokokoo' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Background Color', 'tokokoo' ); ?></span></legend>
							<input type="text" name="tokokoo_theme_options[link_color]" id="link-color" value="<?php echo esc_attr( $options['link_color'] ); ?>" />
							<a href="#" class="pickcolor hide-if-no-js" id="link-color-example"></a>
							<input type="button" class="pickcolor button hide-if-no-js" value="<?php esc_attr_e( 'Select a Color', 'tokokoo' ); ?>" />
							<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div>
						</fieldset>
					</td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Link BuddyPress', 'tokokoo' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'BuddyPress Integration', 'tokokoo' ); ?></span></legend>
							
							 <div class="section support-section">
							 <p class="support-content">So you've activated BuddyPress huh? Great! This theme is compatible without any additional configuration. However, you may want to know about some of the additional pages that you can link to in your navigation and elsewhere...</p>
							 <ul>
							 <li><strong>Activity Page:</strong> <a href="<?php bloginfo('url');?>/activity"><?php bloginfo('url');?>/activity</a></li>
							 <li><strong>Members Page:</strong> <a href="<?php bloginfo('url');?>/members"><?php bloginfo('url');?>/members</a></li>
							 <li><strong>Groups Page:</strong> <a href="<?php bloginfo('url');?>/groups"><?php bloginfo('url');?>/groups</a></li>
							 <li><strong>Forums Page:</strong> <a href="<?php bloginfo('url');?>/forums"><?php bloginfo('url');?>/forums</a> (Only if you have forums setup)</li>
							 <li><strong>Register Page:</strong> <a href="<?php bloginfo('url');?>/register"><?php bloginfo('url');?>/register</a> (Only if you allow registrations. Logged in users will be redirected to the homepage.)</li>
							 </ul>
							 <p><strong>NOTE: These pages will only work if your permalinks are set to anything other than default. This is a requirement for BuddyPress to work correctly.</strong></p>
							 </div>
							 
						</fieldset>
					</td>
				</tr>

			</table>

			<?php submit_button(); ?>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate form input. Accepts an array, return a sanitized array.
 *
 * @see tokokoo_theme_options_init()
 * @todo set up Reset Options action
 *
 * @since Toko Online 1.0
 */
function tokokoo_theme_options_validate( $input ) {
	$output = $defaults = tokokoo_get_default_theme_options();

	// Color scheme must be in our array of color scheme options
	if ( isset( $input['color_scheme'] ) && array_key_exists( $input['color_scheme'], tokokoo_color_schemes() ) )
		$output['color_scheme'] = $input['color_scheme'];

	// Our defaults for the link color may have changed, based on the color scheme.
	$output['link_color'] = $defaults['link_color'] = tokokoo_get_default_link_color( $output['color_scheme'] );

	// Link color must be 3 or 6 hexadecimal characters
	if ( isset( $input['link_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['link_color'] ) )
		$output['link_color'] = '#' . strtolower( ltrim( $input['link_color'], '#' ) );

	// Theme layout must be in our array of theme layout options
	if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], tokokoo_layouts() ) )
		$output['theme_layout'] = $input['theme_layout'];

	return apply_filters( 'tokokoo_theme_options_validate', $output, $input, $defaults );
}

/**
 * Enqueue the styles for the current color scheme.
 *
 * @since Toko Online 1.0
 */
function tokokoo_enqueue_color_scheme() {
	$options = tokokoo_get_theme_options();
	$color_scheme = $options['color_scheme'];

	if ( 'dark' == $color_scheme )
		wp_enqueue_style( 'dark', get_template_directory_uri() . '/colors/dark.css', array(), null );

	do_action( 'tokokoo_enqueue_color_scheme', $color_scheme );
}
add_action( 'wp_enqueue_scripts', 'tokokoo_enqueue_color_scheme' );

/**
 * Add a style block to the theme for the current link color.
 *
 * This function is attached to the wp_head action hook.
 *
 * @since Toko Online 1.0
 */
function tokokoo_print_link_color_style() {
	$options = tokokoo_get_theme_options();
	$link_color = $options['link_color'];

	$default_options = tokokoo_get_default_theme_options();

	// Don't do anything if the current link color is the default.
	if ( $default_options['link_color'] == $link_color )
		return;
?>
	<style>
		/* Link color */
		a,
		#site-title a:focus,
		#site-title a:hover,
		#site-title a:active,
		.entry-title a:hover,
		.entry-title a:focus,
		.entry-title a:active,
		.widget_tokokoo_ephemera .comments-link a:hover,
		section.recent-posts .other-recent-posts a[rel="bookmark"]:hover,
		section.recent-posts .other-recent-posts .comments-link a:hover,
		.format-image footer.entry-meta a:hover,
		#site-generator a:hover {
			color: <?php echo $link_color; ?>;
		}
		section.recent-posts .other-recent-posts .comments-link a:hover {
			border-color: <?php echo $link_color; ?>;
		}
		article.feature-image.small .entry-summary p a:hover,
		.entry-header .comments-link a:hover,
		.entry-header .comments-link a:focus,
		.entry-header .comments-link a:active,
		.feature-slider a.active {
			background-color: <?php echo $link_color; ?>;
		}
	</style>
<?php
}
add_action( 'wp_head', 'tokokoo_print_link_color_style' );

/**
 * Adds Toko Online layout classes to the array of body classes.
 *
 * @since Toko Online 1.0
 */
function tokokoo_layout_classes( $existing_classes ) {
	$options = tokokoo_get_theme_options();
	$current_layout = $options['theme_layout'];

	if ( in_array( $current_layout, array( 'content-sidebar', 'sidebar-content' ) ) )
		$classes = array( 'two-column' );
	else
		$classes = array( 'one-column' );

	if ( 'content-sidebar' == $current_layout )
		$classes[] = 'right-sidebar';
	elseif ( 'sidebar-content' == $current_layout )
		$classes[] = 'left-sidebar';
	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'tokokoo_layout_classes', $classes, $current_layout );

	return array_merge( $existing_classes, $classes );
}
add_filter( 'body_class', 'tokokoo_layout_classes' );